@@ -2,6 +2,9 @@ package App::Kaizendo::Web::ControllerRole::Aspect;
 use MooseX::MethodAttributes::Role;
 use namespace::autoclean;
 
+sub aspect_base : Chained('base') PathPart(';') CaptureArgs(0) {
+}
+
 =head1 NAME
 
 App::Kaizendo::Web::ControllerRole::Aspect
@@ -12,11 +15,6 @@ App::Kaizendo::Web::ControllerRole::Aspect
 
 FIXME
 
-=cut
-
-sub aspect_base : Chained('base') PathPart(';') CaptureArgs(0) {
-}
-
 =head2 aspect_list
 
 FIXME
@@ -25,20 +23,12 @@ FIXME
 
 sub aspect_list : Chained('aspect_base') PathPart('') Args(0) {
     my ( $self, $c ) = @_;
-    $c->stash( template => \'Hello world ASPECT' );
+    $c->stash( template => \'Hello world, this is ControllerRole::Aspect list' );
 }
 
-=head1 AUTHORS
+=head1 AUTHORS, COPYRIGHT AND LICENSE
 
-Salve J. Nilsen <sjn@kaizendo.org>
-Thomas Doran <bobtfish@bobtfish.net>
-
-=head1 LICENSE
-
-This library is free software. You can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License v3, AGPLv3.
-
-See L<http://opensource.org/licenses/agpl-v3.html> for details.
+See L<App::Kaizendo> for Authors, Copyright and License information.
 
 =cut
 
