@@ -2,38 +2,14 @@ package App::Kaizendo::Web::ControllerRole::Comment;
 use MooseX::MethodAttributes::Role;
 use namespace::autoclean;
 
-=head1 NAME
-
-App::Kaizendo::Web::ControllerRole::Comment
-
-=head1 METHODS
-
-=head2 comment_base
-
-FIXME
-
-=cut
-
 sub comment_base : Chained('base') PathPart('_c') CaptureArgs(0) {
 }
 
-=head2 comment_list
-
-Lists available comments
-
-=cut
-
 sub comment_list : Chained('comment_base') PathPart('') Args(0)
   ActionClass('REST') {
     my ( $self, $c ) = @_;
 }
 
-=head2 comment_list_GET
-
-GET handler for the comment list method
-
-=cut
-
 sub comment_list_GET {
     my ( $self, $c ) = @_;
     my $accepts = $c->req->headers->{accept};
@@ -52,20 +28,67 @@ sub comment_list_GET {
             },
         },
     );
-    $c->stash( template => \'Hello world _comment_list' );
+    $c->stash( template => \"Hello world, this is ControllerRole::Comment comment_list_GET" );
 }
 
-=head1 AUTHORS
 
-Salve J. Nilsen <sjn@kaizendo.org>
-Thomas Doran <bobtfish@bobtfish.net>
+=head2 comment_show
 
-=head1 LICENSE
+Show a specific comment
 
-This library is free software. You can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License v3, AGPLv3.
+=cut
 
-See L<http://opensource.org/licenses/agpl-v3.html> for details.
+
+sub comment_show : Chained('comment_base') PathPart('') Args(1)
+  ActionClass('REST') {
+    my ( $self, $c ) = @_;
+}
+
+
+
+sub comment_show_GET {
+    my ( $self, $c ) = @_;
+    my $accepts = $c->req->headers->{accept};
+
+    my $id = $c->req->args->[0];
+
+    $self->status_ok(
+        $c,
+        entity => {
+            accepts => $accepts,
+            comment => {
+                from    => q(sjn@pvv.org),
+                re      => q(id00105),
+                id      => $id,
+                content => q(Well done!),
+            },
+        },
+    );
+    $c->stash( template => \"Hello world, this is ControllerRole::Comment comment_show_GET($id)" );
+}
+
+
+=head1 NAME
+
+App::Kaizendo::Web::ControllerRole::Comment
+
+=head1 METHODS
+
+=head2 comment_base
+
+FIXME
+
+=head2 comment_list
+
+Lists available comments
+
+=head2 comment_list_GET
+
+GET handler for the comment list method
+
+=head1 AUTHORS, COPYRIGHT AND LICENSE
+
+See L<App::Kaizendo> for Authors, Copyright and License information.
 
 =cut
 
